import { HTTPClient } from "koajax";
import { DataObject, ListModel } from "mobx-restful";
export const congressClient: HTTPClient<import("koajax").Context>;
export type Base = Record<'updateDate' | 'url', string>;
export const createListStream: <D extends DataObject>() => <K extends string>(key: K) => (this: ListModel<D>) => AsyncGenerator<D, void, unknown>;
export type Depiction = Record<'attribution' | 'imageUrl', string>;
export interface Leadership {
    type: string;
    congress: number;
}
export interface PartyHistory extends Record<`party${'Name' | 'Abbreviation'}`, string> {
    startYear: number;
}
export interface Term extends Record<'congress' | 'startYear' | 'endYear', number>, Record<`state${'Code' | 'Name'}`, string> {
    chamber: 'House' | 'Senate';
    memberType: 'Senator';
}
export interface MemberBase extends Base, Record<'bioguideId' | 'name' | 'partyName' | 'state', string> {
    district?: string;
    depiction: Depiction;
    terms: {
        item: Term[];
    };
}
export interface MemberProfile extends Record<`${'first' | 'last' | 'honorific' | `${'direct' | 'inverted'}Order`}Name`, string> {
    birthYear: string;
}
export interface MemberResume extends Record<`${'' | 'co'}sponsoredLegislation`, {
    count: number;
    url: string;
}> {
    leadership: Leadership[];
    partyHistory: PartyHistory[];
}
export type Member = MemberBase & Partial<MemberProfile & MemberResume>;
export interface MemberOption {
    congress?: number;
    stateCode?: string;
    district?: string;
}
declare const MemberModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<Member, void, any>;
    openStream(filter: Partial<import("mobx-restful").NewData<Member>>): AsyncGenerator<Member, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<Member, Partial<import("mobx-restful").NewData<Member>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">>): Promise<void>;
    loadStream(filter: Partial<import("mobx-restful").NewData<Member>>, newCount: number): Promise<Member[]>;
    loadPage(pageIndex: number, pageSize: number, filter: Partial<import("mobx-restful").NewData<Member>>): Promise<{
        pageData: Member[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: Partial<import("mobx-restful").NewData<Member>>;
    totalCount: number | undefined;
    pageList: Member[][];
    readonly currentPage: Member[];
    readonly pageCount: number;
    readonly allItems: Member[];
    readonly noMore: boolean;
    statistic: Partial<Record<import("web-utility").TypeKeys<Member, import("web-utility").IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<Member, Partial<import("mobx-restful").NewData<Member>>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: Partial<import("mobx-restful").NewData<Member>>): Promise<{
        pageData: Member[];
        totalCount: number;
    }>;
    getList(filter?: Partial<import("mobx-restful").NewData<Member>>, pageIndex?: number, pageSize?: number): Promise<Member[]>;
    refreshList(): Promise<Member[]>;
    getAll(filter?: Partial<import("mobx-restful").NewData<Member>>, pageSize?: number): Promise<Member[]>;
    countAll(keys: import("web-utility").TypeKeys<Member, import("web-utility").IndexKey>[], filter?: Partial<import("mobx-restful").NewData<Member>>, pageSize?: number): Promise<Partial<Record<import("web-utility").TypeKeys<Member, import("web-utility").IndexKey>, Record<string, number>>>>;
    indexOf(id: import("mobx-restful").IDType): number;
    changeOne(data: Partial<Member>, id: import("mobx-restful").IDType, patch?: boolean): void;
    updateOne(data: Partial<import("mobx-restful").NewData<Member>>, id?: import("mobx-restful").IDType): Promise<Member>;
    removeOne(id: import("mobx-restful").IDType): Promise<void>;
    deleteOne(id: import("mobx-restful").IDType): Promise<void>;
    client: import("mobx-restful").RESTClient;
    baseURI: string;
    indexKey: keyof MemberProfile | keyof MemberResume | keyof MemberBase;
    currentOne: Member;
    clearCurrent(): void;
    getOne(id: import("mobx-restful").IDType): Promise<Member>;
    downloading: number;
    uploading: number;
}) & import("web-utility").AbstractClass<ListModel<Member, Partial<import("mobx-restful").NewData<Member>>>>;
export class MemberModel extends MemberModel_base {
    baseURI: string;
    client: import("koajax").HTTPClient<import("koajax").Context>;
    accessor currentLegislation: Record<LegislationModel['type'], LegislationModel> | undefined;
    constructor({ congress, stateCode, district }?: MemberOption);
    openStream: (this: ListModel<Member, Partial<import("mobx-restful").NewData<Member>>>) => AsyncGenerator<Member, void, unknown>;
    getOne(bioguideId: string): Promise<Member>;
}
export interface Legislation extends Record<'number' | 'title' | 'congress' | 'introducedDate' | 'url', string> {
    type: 'S';
    latestAction: Record<'actionDate' | 'text', string>;
    policyArea: {
        name: string;
    };
}
declare const LegislationModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<Legislation, void, any>;
    openStream(filter: Partial<import("mobx-restful").NewData<Legislation>>): AsyncGenerator<Legislation, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<Legislation, Partial<import("mobx-restful").NewData<Legislation>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">>): Promise<void>;
    loadStream(filter: Partial<import("mobx-restful").NewData<Legislation>>, newCount: number): Promise<Legislation[]>;
    loadPage(pageIndex: number, pageSize: number, filter: Partial<import("mobx-restful").NewData<Legislation>>): Promise<{
        pageData: Legislation[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: Partial<import("mobx-restful").NewData<Legislation>>;
    totalCount: number | undefined;
    pageList: Legislation[][];
    readonly currentPage: Legislation[];
    readonly pageCount: number;
    readonly allItems: Legislation[];
    readonly noMore: boolean;
    statistic: Partial<Record<import("web-utility").TypeKeys<Legislation, import("web-utility").IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<Legislation, Partial<import("mobx-restful").NewData<Legislation>>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: Partial<import("mobx-restful").NewData<Legislation>>): Promise<{
        pageData: Legislation[];
        totalCount: number;
    }>;
    getList(filter?: Partial<import("mobx-restful").NewData<Legislation>>, pageIndex?: number, pageSize?: number): Promise<Legislation[]>;
    refreshList(): Promise<Legislation[]>;
    getAll(filter?: Partial<import("mobx-restful").NewData<Legislation>>, pageSize?: number): Promise<Legislation[]>;
    countAll(keys: import("web-utility").TypeKeys<Legislation, import("web-utility").IndexKey>[], filter?: Partial<import("mobx-restful").NewData<Legislation>>, pageSize?: number): Promise<Partial<Record<import("web-utility").TypeKeys<Legislation, import("web-utility").IndexKey>, Record<string, number>>>>;
    indexOf(id: import("mobx-restful").IDType): number;
    changeOne(data: Partial<Legislation>, id: import("mobx-restful").IDType, patch?: boolean): void;
    updateOne(data: Partial<import("mobx-restful").NewData<Legislation>>, id?: import("mobx-restful").IDType): Promise<Legislation>;
    removeOne(id: import("mobx-restful").IDType): Promise<void>;
    deleteOne(id: import("mobx-restful").IDType): Promise<void>;
    client: import("mobx-restful").RESTClient;
    baseURI: string;
    indexKey: keyof Legislation;
    currentOne: Legislation;
    clearCurrent(): void;
    getOne(id: import("mobx-restful").IDType): Promise<Legislation>;
    downloading: number;
    uploading: number;
}) & import("web-utility").AbstractClass<ListModel<Legislation, Partial<import("mobx-restful").NewData<Legislation>>>>;
export class LegislationModel extends LegislationModel_base {
    bioguideId: string;
    type: 'sponsored' | 'cosponsored';
    client: import("koajax").HTTPClient<import("koajax").Context>;
    constructor(bioguideId: string, type?: 'sponsored' | 'cosponsored');
    openStream: (this: ListModel<Legislation, Partial<import("mobx-restful").NewData<Legislation>>>) => AsyncGenerator<Legislation, void, unknown>;
}
export interface Session extends Record<'chamber' | 'startDate' | 'endDate', string> {
    type: 'R';
    number: number;
}
export interface Congress extends Base, Required<Pick<Term, 'startYear' | 'endYear'>> {
    name: string;
    sessions: Session[];
}
declare const CongressModel_base: (abstract new (...args: any[]) => {
    stream?: AsyncGenerator<Congress, void, any>;
    openStream(filter: Partial<import("mobx-restful").NewData<Congress>>): AsyncGenerator<Congress, void, any>;
    clearList(): void;
    clear(): void;
    restoreList({ filter, pageIndex, pageSize, allItems, totalCount }?: Partial<Pick<ListModel<Congress, Partial<import("mobx-restful").NewData<Congress>>>, "filter" | "pageIndex" | "pageSize" | "allItems" | "totalCount">>): Promise<void>;
    loadStream(filter: Partial<import("mobx-restful").NewData<Congress>>, newCount: number): Promise<Congress[]>;
    loadPage(pageIndex: number, pageSize: number, filter: Partial<import("mobx-restful").NewData<Congress>>): Promise<{
        pageData: Congress[];
        totalCount: number;
    }>;
    pageIndex: number;
    pageSize: number;
    filter: Partial<import("mobx-restful").NewData<Congress>>;
    totalCount: number | undefined;
    pageList: Congress[][];
    readonly currentPage: Congress[];
    readonly pageCount: number;
    readonly allItems: Congress[];
    readonly noMore: boolean;
    statistic: Partial<Record<import("web-utility").TypeKeys<Congress, import("web-utility").IndexKey>, Record<string, number>>>;
    turnTo(pageIndex: number, pageSize?: number): ListModel<Congress, Partial<import("mobx-restful").NewData<Congress>>>;
    loadNewPage(pageIndex: number, pageSize: number, filter: Partial<import("mobx-restful").NewData<Congress>>): Promise<{
        pageData: Congress[];
        totalCount: number;
    }>;
    getList(filter?: Partial<import("mobx-restful").NewData<Congress>>, pageIndex?: number, pageSize?: number): Promise<Congress[]>;
    refreshList(): Promise<Congress[]>;
    getAll(filter?: Partial<import("mobx-restful").NewData<Congress>>, pageSize?: number): Promise<Congress[]>;
    countAll(keys: import("web-utility").TypeKeys<Congress, import("web-utility").IndexKey>[], filter?: Partial<import("mobx-restful").NewData<Congress>>, pageSize?: number): Promise<Partial<Record<import("web-utility").TypeKeys<Congress, import("web-utility").IndexKey>, Record<string, number>>>>;
    indexOf(id: import("mobx-restful").IDType): number;
    changeOne(data: Partial<Congress>, id: import("mobx-restful").IDType, patch?: boolean): void;
    updateOne(data: Partial<import("mobx-restful").NewData<Congress>>, id?: import("mobx-restful").IDType): Promise<Congress>;
    removeOne(id: import("mobx-restful").IDType): Promise<void>;
    deleteOne(id: import("mobx-restful").IDType): Promise<void>;
    client: import("mobx-restful").RESTClient;
    baseURI: string;
    indexKey: keyof Congress;
    currentOne: Congress;
    clearCurrent(): void;
    getOne(id: import("mobx-restful").IDType): Promise<Congress>;
    downloading: number;
    uploading: number;
}) & import("web-utility").AbstractClass<ListModel<Congress, Partial<import("mobx-restful").NewData<Congress>>>>;
export class CongressModel extends CongressModel_base {
    baseURI: string;
    client: import("koajax").HTTPClient<import("koajax").Context>;
    accessor thisYearOne: Congress | undefined;
    openStream: (this: ListModel<Congress, Partial<import("mobx-restful").NewData<Congress>>>) => AsyncGenerator<Congress, void, unknown>;
    getOne(id: number): Promise<Congress>;
    getThisYearOne(): Promise<Congress>;
}

//# sourceMappingURL=index.d.ts.map
